@@ -160,6 +160,77 @@ class Client:
         )
         return _json_decode(response)
 
+    def create_app_client(self, generate_secret=True, logout_urls=None, callback_urls=None, **optional_args) -> Dict:
+        """Creates an appClient, calls the POST /appClients endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.create_app_client(name='<name>', description='<description>')
+
+        :param name: Name of the appClient
+        :type name: Optional[str]
+        :param description: Description of the appClient
+        :type description: Optional[str]
+        :param generate_secret: Set to False to ceate a Public app client, default: True
+        :type generate_secret: Boolean
+        :param logout_urls: List of logout urls
+        :type logout_urls: List[str]
+        :param callback_urls: List of callback urls
+        :type callback_urls: List[str]
+        :return: AppClient response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        body = dictstrip({
+            'logoutUrls': logout_urls,
+            'callbackUrls': callback_urls,
+            **optional_args,
+        })
+        body['generateSecret'] = generate_secret
+        return self._make_request(requests.post, '/appClients', body=body)
+
+    def list_app_clients(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
+        """List appClients available, calls the GET /appClients endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.list_app_clients()
+
+        :param max_results: Maximum number of results to be returned
+        :type max_results: Optional[int]
+        :param next_token: A unique token for each page, use the returned token to retrieve the next page.
+        :type next_token: Optional[str]
+        :return: AppClients response from REST API without the content of each appClient
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        params = {
+            'maxResults': max_results,
+            'nextToken': next_token,
+        }
+        return self._make_request(requests.get, '/appClients', params=params)
+
+    def delete_app_client(self, app_client_id: str) -> Dict:
+        """Delete the appClient with the provided appClientId, calls the DELETE /appClients/{appClientId} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.delete_app_client('<app_client_id>')
+
+        :param app_client_id: Id of the appClient
+        :type app_client_id: str
+        :return: AppClient response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.delete, f'/appClients/{app_client_id}')
+
     def create_asset(self, content: Content, **optional_args) -> Dict:
         """Creates an asset, calls the POST /assets endpoint.
 
@@ -252,6 +323,23 @@ class Client:
 
         return self._make_request(requests.patch, f'/assets/{asset_id}', body=optional_args)
 
+    def delete_asset(self, asset_id: str) -> Dict:
+        """Delete the asset with the provided asset_id, calls the DELETE /assets/{assetId} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.delete_asset('<asset_id>')
+
+        :param asset_id: Id of the asset
+        :type asset_id: str
+        :return: Asset response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.delete, f'/assets/{asset_id}')
+
     def create_batch(self, **optional_args) -> Dict:
         """Creates a batch, calls the POST /batches endpoint.
 
@@ -271,6 +359,55 @@ class Client:
         """
         return self._make_request(requests.post, '/batches', body=optional_args)
 
+    def list_batches(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
+        """List batches available, calls the GET /batches endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.list_batches()
+
+        :param max_results: Maximum number of results to be returned
+        :type max_results: Optional[int]
+        :param next_token: A unique token for each page, use the returned token to retrieve the next page.
+        :type next_token: Optional[str]
+        :return: Batches response from REST API without the content of each batch
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        params = {
+            'maxResults': max_results,
+            'nextToken': next_token,
+        }
+        return self._make_request(requests.get, '/batches', params=params)
+
+    def delete_batch(self, batch_id: str, delete_documents=False) -> Dict:
+        """Delete the batch with the provided batch_id, calls the DELETE /batches/{batchId} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.delete_batch('<batch_id>')
+
+        :param batch_id: Id of the batch
+        :type batch_id: str
+        :param delete_documents: Set to true to delete documents in batch before deleting batch
+        :type delete_documents: bool
+        :return: Batch response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        if delete_documents:
+            response = self.delete_documents(batch_id=batch_id)
+            next_token = response['nextToken']
+            while next_token:
+                response = self.delete_documents(batch_id=batch_id, next_token=next_token)
+                next_token = response['nextToken']
+
+        return self._make_request(requests.delete, f'/batches/{batch_id}')
+
     def create_document(
             self,
             content: Content,
@@ -294,7 +431,8 @@ class Client:
         :type consent_id: Optional[str]
         :param batch_id: Id of the associated batch
         :type batch_id: Optional[str]
-        :param ground_truth: List of items {label: value} representing the ground truth values for the document
+        :param ground_truth: List of items {'label': label, 'value': value}
+        representing the ground truth values for the document
         :type ground_truth: Optional[Sequence[Dict[str, str]]]
         :return: Document response from REST API
         :rtype: dict
@@ -347,22 +485,41 @@ class Client:
         }
         return self._make_request(requests.get, '/documents', params=params)
 
-    def delete_documents(self, *, consent_id: Optional[Queryparam] = None) -> Dict:
+    def delete_documents(
+        self,
+        *,
+        consent_id: Optional[Queryparam] = None,
+        batch_id: Optional[Queryparam] = None,
+        max_results: Optional[int] = None,
+        next_token: Optional[str] = None
+    ) -> Dict:
         """Delete documents with the provided consent_id, calls the DELETE /documents endpoint.
 
         >>> from las.client import Client
         >>> client = Client()
         >>> client.delete_documents(consent_id='<consent id>')
 
+        :param batch_id: Ids of the batches to be deleted
+        :type batch_id: Optional[Queryparam]
         :param consent_id: Ids of the consents that marks the owner of the document
         :type consent_id: Optional[Queryparam]
+        :param max_results: Maximum number of documents that will be deleted
+        :type max_results: Optional[int]
+        :param next_token: A unique token for each page, use the returned token to retrieve the next page.
+        :type next_token: Optional[str]
         :return: Documents response from REST API
         :rtype: dict
 
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        return self._make_request(requests.delete, '/documents', params={'consentId': consent_id})
+        params = {
+            'consentId': consent_id,
+            'batchId': batch_id,
+            'nextToken': next_token,
+            'maxResults': max_results,
+        }
+        return self._make_request(requests.delete, '/documents', params=dictstrip(params))
 
     def get_document(self, document_id: str) -> Dict:
         """Get document, calls the GET /documents/{documentId} endpoint.
@@ -403,6 +560,52 @@ class Client:
         """
         return self._make_request(requests.patch, f'/documents/{document_id}', body={'groundTruth': ground_truth})
 
+    def list_logs(
+        self,
+        *,
+        workflow_id: Optional[Queryparam] = None,
+        workflow_execution_id: Optional[Queryparam] = None,
+        transition_id: Optional[Queryparam] = None,
+        transition_execution_id: Optional[Queryparam] = None,
+        max_results: Optional[int] = None,
+        next_token: Optional[str] = None,
+    ) -> Dict:
+        """List logs, calls the GET /logs endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.list_logs()
+
+        :param workflow_id:
+        :type workflow_id: Optional[Queryparam]
+        :param workflow_execution_id:
+        :type workflow_execution_id: Optional[Queryparam]
+        :param transition_id:
+        :type transition_id: Optional[Queryparam]
+        :param transition_execution_id:
+        :type transition_execution_id: Optional[Queryparam]
+        :param max_results: Maximum number of results to be returned
+        :type max_results: Optional[int]
+        :param next_token: A unique token for each page, use the returned token to retrieve the next page.
+        :type next_token: Optional[str]
+        :return: Logs response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        url = '/logs'
+        params = {
+            'maxResults': max_results,
+            'nextToken': next_token,
+            'workflowId': workflow_id,
+            'workflowExecutionId': workflow_execution_id,
+            'transitionId': transition_id,
+            'transitionExecutionId': transition_execution_id,
+        }
+
+        return self._make_request(requests.get, url, params=dictstrip(params))
+
     def get_log(self, log_id) -> Dict:
         """get log, calls the GET /logs/{logId} endpoint.
 
@@ -583,6 +786,23 @@ class Client:
         body.update(**optional_args)
         return self._make_request(requests.patch, f'/secrets/{secret_id}', body=body)
 
+    def delete_secret(self, secret_id: str) -> Dict:
+        """Delete the secret with the provided secret_id, calls the DELETE /secrets/{secretId} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.delete_secret('<secret_id>')
+
+        :param secret_id: Id of the secret
+        :type secret_id: str
+        :return: Secret response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.delete, f'/secrets/{secret_id}')
+
     def create_transition(
         self,
         transition_type: str,
@@ -694,6 +914,9 @@ class Client:
         *,
         in_schema: Optional[dict] = None,
         out_schema: Optional[dict] = None,
+        assets: Optional[dict] = None,
+        environment: Optional[dict] = None,
+        environment_secrets: Optional[list] = None,
         **optional_args,
     ) -> Dict:
         """Updates a transition, calls the PATCH /transitions/{transitionId} endpoint.
@@ -705,7 +928,7 @@ class Client:
         >>> client.update_transition('<transition-id>', name='<name>', description='<description>')
 
         :param transition_id: Id of the transition
-        :type name: str
+        :type transition_id: str
         :param name: Name of the transition
         :type name: Optional[str]
         :param description: Description of the transition
@@ -714,6 +937,13 @@ class Client:
         :type in_schema: Optional[dict]
         :param out_schema: Json-schema that defines the output of the transition
         :type out_schema: Optional[dict]
+        :param assets: A dictionary where the values are assetIds that can be used in a manual transition
+        :type assets: Optional[dict]
+        :param environment: Environment variables to use for a docker transition
+        :type environment: Optional[dict]
+        :param environment_secrets:
+        A list of secretIds that contains environment variables to use for a docker transition
+        :type environment_secrets: Optional[list]
         :return: Transition response from REST API
         :rtype: dict
 
@@ -723,6 +953,9 @@ class Client:
         body = dictstrip({
             'inputJsonSchema': in_schema,
             'outputJsonSchema': out_schema,
+            'assets': assets,
+            'environment': environment,
+            'environmentSecrets': environment_secrets,
         })
         body.update(**optional_args)
         return self._make_request(requests.patch, f'/transitions/{transition_id}', body=body)
@@ -1093,7 +1326,14 @@ class Client:
         """
         return self._make_request(requests.get, f'/workflows/{workflow_id}')
 
-    def update_workflow(self, workflow_id: str, **optional_args) -> Dict:
+    def update_workflow(
+        self,
+        workflow_id: str,
+        *,
+        error_config: Optional[dict] = None,
+        completed_config: Optional[dict] = None,
+        **optional_args,
+    ) -> Dict:
         """Updates a workflow, calls the PATCH /workflows/{workflowId} endpoint.
 
         >>> import json
@@ -1108,13 +1348,22 @@ class Client:
         :type name: Optional[str]
         :param description: Description of the workflow
         :type description: Optional[str]
+        :param error_config: Configuration of error handler
+        :type error_config: Optional[dict]
+        :param completed_config: Configuration of a job to run whenever a workflow execution ends
+        :type completed_config: Optional[dict]
         :return: Workflow response from REST API
         :rtype: dict
 
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        return self._make_request(requests.patch, f'/workflows/{workflow_id}', body=optional_args)
+        body = dictstrip({
+            'errorConfig': error_config,
+            'completedConfig': completed_config,
+        })
+        body.update(**optional_args)
+        return self._make_request(requests.patch, f'/workflows/{workflow_id}', body=body)
 
     def delete_workflow(self, workflow_id: str) -> Dict:
         """Delete the workflow with the provided workflow_id, calls the DELETE /workflows/{workflowId} endpoint.
